[−][src]Crate dbus_message_parser
Structs
| BUS_REGEX | The regular expression for a valid bus name. |
| Bus | This represents a bus name. |
| Decoder | |
| ERROR_REGEX | The regular expression for a valid error name. |
| Encoder | |
| Error | This represents an error name. |
| INTERFACE_REGEX | The regular expression for a valid interface name. |
| Interface | This represents an interface name. |
| MEMBER_REGEX | The regular expression for a valid member name. |
| Member | This represents a member name. |
| Message | This represents a DBus message. |
| MessageFlags | A struct representing the message flags. |
| MessageHeader | This represents a DBus message header. |
| OBJECT_PATH_ELEMENT_REGEX | The regular expression for a element of an object path. |
| OBJECT_PATH_REGEX | The regular expression for a valid object path. |
| ObjectPath | This represents a object path. |
Enums
| BusError | An enum representing all errors, which can occur during the handling of a |
| DecodeError | An enum representing all errors, which can occur during the decoding. |
| EncodeError | An enum representing all errors, which can occur during the encoding. |
| ErrorError | An enum representing all errors, which can occur during the handling of a |
| Header | An enum representing a header field. |
| InterfaceError | An enum representing all errors, which can occur during the handling of a |
| MemberError | An enum representing all errors, which can occur during the handling of a |
| MessageType | An enum representing the message type. |
| ObjectPathError | An enum representing all errors, which can occur during the handling of a |
| Value | An enum representing a DBus value. |
Constants
| MAXIMUM_NAME_LENGTH |
Type Definitions
| DecodeResult | |
| EncodeResult |