Enum dbus_message_parser::decode::DecodeError [−][src]
pub enum DecodeError {
Show 25 variants
NotEnoughBytes(usize, usize),
InvalidBoolean(u32),
Utf8Error(Utf8Error),
StringNotNull(u8),
BusError(BusError),
ObjectPathError(ObjectPathError),
InterfaceError(InterfaceError),
MemberError(MemberError),
ErrorError(ErrorError),
SignatureError(TypeError),
StructError(StructError),
Padding(u8),
ArrayTooBig(u32),
ArrayInvalidLength(usize, usize),
Endianness(u8),
MessageType(u8),
MessageFlags(u8),
BodyLengthZero(Vec<Type>),
BodySignatureMissing(u32),
NotEnoughFds(usize, usize),
BodyLength(usize, usize),
MessageHeaderError(MessageHeaderError),
MessageHeaderFieldsError(MessageHeaderFieldsError),
IntegerOverflow(usize, usize),
VariantDepth(u8),
}Expand description
An enum representing all errors, which can occur during the decoding.
Variants
NotEnoughBytes(usize, usize)
InvalidBoolean(u32)
Tuple Fields
0: u32Utf8Error(Utf8Error)
Tuple Fields
0: Utf8ErrorStringNotNull(u8)
Tuple Fields
0: u8BusError(BusError)
Tuple Fields
0: BusErrorObjectPathError(ObjectPathError)
Tuple Fields
InterfaceError(InterfaceError)
Tuple Fields
MemberError(MemberError)
Tuple Fields
0: MemberErrorErrorError(ErrorError)
Tuple Fields
0: ErrorErrorSignatureError(TypeError)
Tuple Fields
0: TypeErrorStructError(StructError)
Tuple Fields
0: StructErrorPadding(u8)
Tuple Fields
0: u8ArrayTooBig(u32)
Tuple Fields
0: u32ArrayInvalidLength(usize, usize)
Endianness(u8)
Tuple Fields
0: u8MessageType(u8)
Tuple Fields
0: u8MessageFlags(u8)
Tuple Fields
0: u8BodyLengthZero(Vec<Type>)
BodySignatureMissing(u32)
Tuple Fields
0: u32NotEnoughFds(usize, usize)
BodyLength(usize, usize)
MessageHeaderError(MessageHeaderError)
Tuple Fields
MessageHeaderFieldsError(MessageHeaderFieldsError)
Tuple Fields
IntegerOverflow(usize, usize)
VariantDepth(u8)
Tuple Fields
0: u8Trait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.