Enum dbus_message_parser::encode::EncodeError [−][src]
pub enum EncodeError {
ArrayTooBig(usize),
BodyLengthZero(Vec<Type>),
BodySignatureMissing(u32),
SignatureError(TypeError),
}Expand description
An enum representing all errors, which can occur during the encoding.
Variants
ArrayTooBig(usize)
Tuple Fields
0: usizeBodyLengthZero(Vec<Type>)
BodySignatureMissing(u32)
Tuple Fields
0: u32SignatureError(TypeError)
Tuple Fields
0: TypeErrorTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.