Struct dbus_message_parser::message::Message[][src]

pub struct Message { /* fields omitted */ }
This represents a DBus message.

Implementations

The decode a Message and returns the offset.

The decode a Message and returns the offset and the offset of the given FDs.

Create a Message object.

Create a Message object as a MethodCall.

Create a Message object as a Signal.

Create a Message to retrieve property value.

Create a Message to retrieve property value.

Create a Message to retrieve property value.

Get the serial number.

Set the serial number.

Get the ReplySerial number, if there is one in the header field.

Get the Path, if there is one in the header field.

It is true if the message contains an Interface in the header fields.

Get the Interface, if there is one in the header fields.

It is true if the message contains an Member in the header fields.

Get the Member, if there is one in the header field.

It is true if the message contains an ErrorName in the header fields.

Get the ErrorName, if there is one in the header field.

Get the Sender, if there is one in the header field.

Get the Destination, if there is one in the header field.

Get the Signature, if there is one in the header field.

Get the UnixFDs, if there is one in the header field.

It is true if the message contains an UnixFDs in the header fields.

Add a new value to the body.

Create a message return from this Message. Only works if this Message is a MethodCall.

Create a unknown property error message from this Message.

Create a unknown path error message from this Message.

Create a unknown interface error message from this Message.

Create a unknown member error message from this Message.

Create an invalid args error message from this Message.

Create an error message from this Message.

Get the body.

Get the message type.

Split the Message object into the header and the body.