Struct dbus_message_parser::message::MessageHeaderFields [−][src]
pub struct MessageHeaderFields {
pub path: Option<ObjectPath>,
pub interface: Option<Interface>,
pub member: Option<Member>,
pub error_name: Option<Error>,
pub reply_serial: Option<u32>,
pub destination: Option<Bus>,
pub sender: Option<Bus>,
pub signature: Option<Vec<Type>>,
pub unix_fds: Option<u32>,
}Expand description
An struct representing the header fields.
Fields
path: Option<ObjectPath>interface: Option<Interface>member: Option<Member>error_name: Option<Error>reply_serial: Option<u32>destination: Option<Bus>sender: Option<Bus>signature: Option<Vec<Type>>unix_fds: Option<u32>Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more