Enum dbus_message_parser::value::ErrorError [−][src]
pub enum ErrorError {
ElementBeginDigit,
ElementBeginDot,
EndDot,
Empty,
Elements,
ExceedMaximum(usize),
InvalidChar(u8),
}Expand description
An enum representing all errors, which can occur during the handling of a Error.
Variants
ExceedMaximum(usize)InvalidChar(u8)Trait Implementations
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.