Enum dbus_message_parser::value::MemberError [−][src]
An enum representing all errors, which can occur during the handling of a Member.
Variants
Empty
BeginDigit
ExceedMaximum(usize)
Tuple Fields
0: usizeInvalidChar(u8)
Tuple Fields
0: u8Trait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.