Enum dbus_message_parser::value::ObjectPathError [−][src]
pub enum ObjectPathError {
BeginAlphanumericAndUnderscoreAndHyphen,
EndSlash,
Empty,
ElementEmtpy,
InvalidChar(u8),
}Expand description
An enum representing all errors, which can occur during the handling of a ObjectPath.
Variants
BeginAlphanumericAndUnderscoreAndHyphen
EndSlash
Empty
ElementEmtpy
InvalidChar(u8)
Tuple Fields
0: u8Trait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.