Enum dbus_message_parser::value::WellKnownBusNameError [−][src]
pub enum WellKnownBusNameError {
BeginDigit,
BeginDot,
EndDot,
ElementBeginDigit,
ElementBeginDot,
Empty,
Elements,
ExceedMaximum(usize),
InvalidChar(u8),
}Expand description
An enum representing all errors, which can occur during the handling of a WellKnownBusName.
Variants
BeginDigit
BeginDot
EndDot
ElementBeginDigit
ElementBeginDot
Empty
Elements
ExceedMaximum(usize)
Tuple Fields
0: usizeInvalidChar(u8)
Tuple Fields
0: u8Trait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.