Enum dbus_message_parser::decode::DecodeError [−][src]
pub enum DecodeError {
Show 26 variants
NotEnoughBytes(usize, usize),
InvalidBoolean(u32),
Utf8Error(Utf8Error),
StringNotNull(u8),
BusError(BusError),
ObjectPathError(ObjectPathError),
InterfaceError(InterfaceError),
MemberError(MemberError),
ErrorError(ErrorError),
SignatureError(TypeError),
StructError(StructError),
Padding(u8),
ArrayTooBig(u32),
ArrayInvalidLength(usize, usize),
Endianness(u8),
MessageType(u8),
MessageFlags(u8),
MessageHeaderFieldDouble(MessageHeaderField),
BodyLengthZero(Vec<Type>),
BodySignatureMissing(u32),
NotEnoughFds(usize, usize),
BodyLength(usize, usize),
MessageHeaderError(MessageHeaderError),
MessageHeaderFieldError(MessageHeaderFieldError),
IntegerOverflow(usize, usize),
VariantDepth(u8),
}Expand description
An enum representing all errors, which can occur during the decoding.
Variants
InvalidBoolean(u32)Utf8Error(Utf8Error)StringNotNull(u8)BusError(BusError)ObjectPathError(ObjectPathError)InterfaceError(InterfaceError)MemberError(MemberError)ErrorError(ErrorError)SignatureError(TypeError)StructError(StructError)Padding(u8)ArrayTooBig(u32)Endianness(u8)MessageType(u8)MessageFlags(u8)MessageHeaderFieldDouble(MessageHeaderField)BodySignatureMissing(u32)MessageHeaderError(MessageHeaderError)MessageHeaderFieldError(MessageHeaderFieldError)VariantDepth(u8)Trait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.