Struct dbus_message_parser::message::MessageHeader [−][src]
pub struct MessageHeader { /* fields omitted */ }Expand description
This represents a DBus message header.
Implementations
pub fn new(
is_le: bool,
message_type: MessageType,
message_flags: MessageFlags,
version: u8,
serial: u32,
fields: HeaderFields
) -> Result<Header, HeaderError>
pub fn new(
is_le: bool,
message_type: MessageType,
message_flags: MessageFlags,
version: u8,
serial: u32,
fields: HeaderFields
) -> Result<Header, HeaderError>
Create a [MessageHeader] object. It can fail if the required header fields are not
present.
Get the serial number.
Get the Path, if there is one in the header field.
Get the Interface, if there is one in the header field.
It is true if the message contains an Interface in the header fields.
Get the Member, if there is one in the header field.
It is true if the message contains an Member in the header fields.
Get the ErrorName, if there is one in the header field.
It is true if the message contains an ErrorName in the header fields.
Get the Destination, if there is one in the header field.
It is true if the message contains a Destination in the header fields.
Get the Sender, if there is one in the header field.
It is true if the message contains a Sender in the header fields.
Get the ReplySerial number, if there is one in the header field.
It is true if the message contains an ReplySerial in the header fields.
Get the Signature, if there is one in the header field.
It is true if the message contains a Signature in the header fields.
Get the UnixFDs, if there is one in the header field.
It is true if the message contains an UnixFDs in the header fields.
Create a message return from this Message.
Only works if this Message is a MethodCall.
Create a unknown property error message from this Message.
Create a unknown path error message from this Message.
Create a unknown interface error message from this Message.
Create a unknown member error message from this Message.
Create an invalid args error message from this Message.
Create an error message from this Message.
Get the message type.